pub enum Mode {
Static,
Dynamic,
}Expand description
Define the runtime mode for this endpount
In dynamic mode any new peer can introduce itself to start a link, while in static mode only known peers will be accepted.
Variants